@@ -48,7 +48,6 @@ my $EVENTS_TAG      = 'events';
 my $FIRST_NAME_TAG  = 'first_name';
 my $LAST_NAME_TAG   = 'last_name';
 my $USER_TAG        = 'email-reminder_user';
-my $AUTHOR_WISHES_TAG = 'send_author_wishes';
 
 my $TYPE_ATTR       = 'type';
 
@@ -297,18 +296,6 @@ sub set_user_lname
     return EmailReminder::Utils::set_node_value($self->{USER_NODE}, $LAST_NAME_TAG, $new_lname);
 }
 
-sub get_author_wishes
-{
-    my $self = shift;
-    return EmailReminder::Utils::get_node_value($self->{USER_NODE}, $AUTHOR_WISHES_TAG);
-}
-
-sub set_author_wishes
-{
-    my ($self, $new_author_wishes) = @_;
-    return EmailReminder::Utils::set_node_value($self->{USER_NODE}, $AUTHOR_WISHES_TAG, $new_author_wishes);
-}
-
 # Return 0 if the email was ignored (invalid)
 sub set_user_email
 {
