@@ -170,7 +170,7 @@ sub get_message_body
     my $self = shift;
 
     # event details
-    my $when      = $self->{"WHEN"};
+    my $when      = $self->{"WHEN"} || '';
     my $name      = $self->get_name();
     my $occurence = $self->get_occurence();
     my $th        = EmailReminder::Utils::get_th($occurence);
